import { h, Host } from "@stencil/core";
export class StackSectionMap {
    constructor() {
        this.markerInstances = [];
        this.polygonLayerId = 'polygon-layer';
        this.zoom = 1;
        this.height = 400;
        this.center = [0, 0];
        this.markers = [];
        this.mapStyle = 'light-v11';
        this.markerColor = 'var(--md-sys-color-primary)';
        this.polygonColor = 'var(--md-sys-color-primary)';
    }
    async loadMapboxResources() {
        if (window.mapboxgl)
            return;
        // Load CSS
        const linkEl = document.createElement('link');
        linkEl.rel = 'stylesheet';
        linkEl.href = 'https://api.mapbox.com/mapbox-gl-js/v3.3.0/mapbox-gl.css';
        document.head.appendChild(linkEl);
        // Load and wait for the script
        await new Promise((resolve, reject) => {
            const scriptEl = document.createElement('script');
            scriptEl.src = 'https://api.mapbox.com/mapbox-gl-js/v3.3.0/mapbox-gl.js';
            scriptEl.onload = resolve;
            scriptEl.onerror = reject;
            document.head.appendChild(scriptEl);
        });
    }
    async componentDidLoad() {
        await this.loadMapboxResources();
        if (!this.accessToken) {
            console.error('Mapbox access token is required');
            return;
        }
        window.mapboxgl.accessToken = this.accessToken;
        this.mapInstance = new window.mapboxgl.Map({
            container: this.mapContainer,
            style: STYLE_MAP[this.mapStyle],
            center: this.center,
            zoom: this.zoom,
        });
        // Wait for both map load and style load before adding markers and polygon
        this.mapInstance.on('style.load', () => {
            this.addMarkers();
            this.addPolygon();
        });
    }
    addMarkers() {
        // Clear existing markers
        this.markerInstances.forEach(marker => marker.remove());
        this.markerInstances = [];
        // Add new markers
        this.markers.forEach(coordinates => {
            const marker = new window.mapboxgl.Marker({
                color: this.markerColor,
            })
                .setLngLat(coordinates)
                .addTo(this.mapInstance);
            this.markerInstances.push(marker);
        });
        // Fit map to markers if there are any
        if (this.markers.length > 0) {
            const bounds = new window.mapboxgl.LngLatBounds();
            this.markers.forEach(coordinates => {
                bounds.extend(coordinates);
            });
            this.mapInstance.fitBounds(bounds, {
                padding: 50, // Add some padding around the markers
                maxZoom: this.zoom, // Prevent zooming in too close
            });
        }
    }
    addPolygon() {
        // Remove existing layers if they exist
        if (this.mapInstance.getLayer(this.polygonLayerId)) {
            this.mapInstance.removeLayer(this.polygonLayerId);
            this.mapInstance.removeLayer(`${this.polygonLayerId}-label`);
            this.mapInstance.removeSource(this.polygonLayerId);
        }
        const computedColor = getComputedStyle(document.documentElement).getPropertyValue(this.polygonColor.replace('var(', '').replace(')', '')).trim();
        // Calculate the center point of the polygon for label placement
        const bounds = new window.mapboxgl.LngLatBounds();
        this.polygon.coordinates.forEach(coordinate => {
            bounds.extend(coordinate);
        });
        const center = bounds.getCenter();
        // Add the polygon data as a source
        this.mapInstance.addSource(this.polygonLayerId, {
            type: 'geojson',
            data: {
                type: 'Feature',
                properties: {
                    label: this.polygon.label,
                    center: [center.lng, center.lat],
                },
                geometry: {
                    type: 'Polygon',
                    coordinates: [this.polygon.coordinates],
                },
            },
        });
        // Add the polygon fill layer
        this.mapInstance.addLayer({
            id: this.polygonLayerId,
            type: 'fill',
            source: this.polygonLayerId,
            paint: {
                'fill-color': computedColor,
                'fill-opacity': 0.3,
                'fill-outline-color': computedColor,
            },
        });
        // Add the label layer
        this.mapInstance.addLayer({
            id: `${this.polygonLayerId}-label`,
            type: 'symbol',
            source: this.polygonLayerId,
            layout: {
                'text-field': ['get', 'label'],
                'text-anchor': 'center',
                'text-size': 12,
                'text-justify': 'center',
                'text-offset': [0, 0],
            },
            paint: {
                'text-color': computedColor,
                'text-halo-color': '#ffffff',
                'text-halo-width': 2,
            },
        });
        // Fit map to polygon bounds
        this.mapInstance.fitBounds(bounds, {
            padding: 100,
        });
    }
    disconnectedCallback() {
        var _a;
        // Remove both layers before removing map
        if ((_a = this.mapInstance) === null || _a === void 0 ? void 0 : _a.getLayer(this.polygonLayerId)) {
            this.mapInstance.removeLayer(this.polygonLayerId);
            this.mapInstance.removeLayer(`${this.polygonLayerId}-label`);
            this.mapInstance.removeSource(this.polygonLayerId);
        }
        // Remove markers before removing map
        this.markerInstances.forEach(marker => marker.remove());
        if (this.mapInstance) {
            this.mapInstance.remove();
        }
    }
    render() {
        return (h(Host, { key: '3e57934666c55c2d13f04bf918fbb50305f773ca' }, h("div", { key: 'c6bd95f5e2181cbc06dbde79ca5e688e6bb5d419', class: "container", style: { height: `${this.height}px` } }, h("div", { key: '00ab1e9dd566d525c8b06ebbb34bc6c72a1a8c18', ref: el => (this.mapContainer = el), style: { width: '100%', height: '100%' } }))));
    }
    static get is() { return "stack-section-map"; }
    static get originalStyleUrls() {
        return {
            "$": ["stack-section-map.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["stack-section-map.css"]
        };
    }
    static get properties() {
        return {
            "accessToken": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "access-token",
                "reflect": false
            },
            "zoom": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "zoom",
                "reflect": false,
                "defaultValue": "1"
            },
            "height": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "height",
                "reflect": false,
                "defaultValue": "400"
            },
            "center": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "[number, number]",
                    "resolved": "[number, number]",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[0, 0]"
            },
            "markers": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "[number, number][]",
                    "resolved": "[number, number][]",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[]"
            },
            "mapStyle": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "'streets-v12' | 'outdoors-v12' | 'light-v11' | 'dark-v11' | 'satellite-v9' | 'satellite-streets-v12' | 'navigation-day-v1' | 'navigation-night-v1'",
                    "resolved": "\"dark-v11\" | \"light-v11\" | \"navigation-day-v1\" | \"navigation-night-v1\" | \"outdoors-v12\" | \"satellite-streets-v12\" | \"satellite-v9\" | \"streets-v12\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "map-style",
                "reflect": false,
                "defaultValue": "'light-v11'"
            },
            "markerColor": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "`var(--md-sys-color-${string})`",
                    "resolved": "`var(--md-sys-color-${string})`",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "marker-color",
                "reflect": false,
                "defaultValue": "'var(--md-sys-color-primary)'"
            },
            "polygonColor": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "`var(--md-sys-color-${string})`",
                    "resolved": "`var(--md-sys-color-${string})`",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "polygon-color",
                "reflect": false,
                "defaultValue": "'var(--md-sys-color-primary)'"
            },
            "polygon": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "Polygon",
                    "resolved": "{ readonly coordinates: [number, number][]; readonly label: string; }",
                    "references": {
                        "Polygon": {
                            "location": "local",
                            "path": "/home/runner/work/trust-stack-js/trust-stack-js/packages/canvas-components/src/components/stack-section-map/stack-section-map.tsx",
                            "id": "src/components/stack-section-map/stack-section-map.tsx::Polygon"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get states() {
        return {
            "mapInstance": {}
        };
    }
}
const STYLE_MAP = {
    'streets-v12': 'mapbox://styles/mapbox/streets-v12',
    'outdoors-v12': 'mapbox://styles/mapbox/outdoors-v12',
    'light-v11': 'mapbox://styles/mapbox/light-v11',
    'dark-v11': 'mapbox://styles/mapbox/dark-v11',
    'satellite-v9': 'mapbox://styles/mapbox/satellite-v9',
    'satellite-streets-v12': 'mapbox://styles/mapbox/satellite-streets-v12',
    'navigation-day-v1': 'mapbox://styles/mapbox/navigation-day-v1',
    'navigation-night-v1': 'mapbox://styles/mapbox/navigation-night-v1',
};
//# sourceMappingURL=stack-section-map.js.map
